tubes core for gleam is a pure gleam irc-ing library. it is a sister project of the tubes irc client.
what it does
- line parsing
- more to come!
add it to your thing
like this:
gleam add tubes
go to https://hexdocs.pm/tubes for “documentation”.
tubes core for gleam is a pure gleam irc-ing library. it is a sister project of the tubes irc client.
like this:
gleam add tubes
go to https://hexdocs.pm/tubes for “documentation”.